@@ -31,11 +31,13 @@ def converted_async_test(test_tasks, func, timeout, *args, **kwargs):
     __tracebackhide__ = True
 
     info = {}
-    loop = asyncio.get_event_loop()
+    loop = asyncio.get_event_loop_policy().get_event_loop()
 
     def look_at_task(t):
         test_tasks[loop].append(t)
 
+    info["func"] = func
+
     return _run_and_raise(
         loop, info, func, async_runner(func, timeout, info, args, kwargs), look_at_task
     )
@@ -158,8 +160,8 @@ def convert_async_coroutine_fixture(fixturedef, request, node):
     def override(extra, *args, **kwargs):
         __tracebackhide__ = True
 
-        info = {}
-        loop = asyncio.get_event_loop()
+        info = {"func": func}
+        loop = asyncio.get_event_loop_policy().get_event_loop()
         return _run_and_raise(loop, info, func, async_runner(func, timeout, info, args, kwargs))
 
     fixturedef.func = _wrap(fixturedef, [], override, func)
@@ -176,16 +178,22 @@ def convert_async_gen_fixture(fixturedef, request, node):
         __tracebackhide__ = True
 
         request = extra["request"]
-        loop = asyncio.get_event_loop()
+        loop = asyncio.get_event_loop_policy().get_event_loop()
 
         timeout = _find_async_timeout(fixturedef.func, node)
         gen_obj = generator(*args, **kwargs)
 
+        info = {"gen_obj": gen_obj}
+
         def finalizer():
             """Yield again, to finalize."""
             __tracebackhide__ = True
 
-            info = {}
+            nonlocal info
+            if "ran_once" not in info:
+                return
+
+            info = {"gen_obj": gen_obj, "finalizer": True}
 
             async def async_finalizer():
                 __tracebackhide__ = True
@@ -201,9 +209,11 @@ def convert_async_gen_fixture(fixturedef, request, node):
 
         request.addfinalizer(finalizer)
 
-        info = {}
         return _run_and_raise(
-            loop, info, generator, async_runner(gen_obj.__anext__, timeout, info, (), {}),
+            loop,
+            info,
+            generator,
+            async_runner(gen_obj.__anext__, timeout, info, (), {}),
         )
 
     fixturedef.func = _wrap(fixturedef, ["request"], override, generator)
@@ -236,3 +246,5 @@ async def async_runner(func, timeout, info, args, kwargs):
         exc_info = sys.exc_info()
         e = exc_info[1]
         info["e"] = e
+    finally:
+        info["ran_once"] = True
